==> haskell-pandoc-types-1.17.6-4-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-pandoc-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pandoc-types
version: 1.17.6
id: pandoc-types-1.17.6-KQKyc92FMn2LeLAWyyofXw
key: pandoc-types-1.17.6-KQKyc92FMn2LeLAWyyofXw
license: BSD-3-Clause
copyright: (c) 2006-2019 John MacFarlane
maintainer: jgm@berkeley.edu
author: John MacFarlane
homepage: https://pandoc.org/
synopsis: Types for representing a structured document
description:
    @Text.Pandoc.Definition@ defines the '\''Pandoc'\'' data
    structure, which is used by pandoc to represent
    structured documents.  This module used to live
    in the pandoc package, but starting with pandoc 1.7, it
    has been split off, so that other packages can use it
    without drawing in all of pandoc'\''s dependencies, and
    pandoc itself can depend on packages (like citeproc-hs)
    that use them.
    .
    @Text.Pandoc.Builder@ provides functions for building
    up @Pandoc@ structures programmatically.
    .
    @Text.Pandoc.Generic@ provides generic functions for
    manipulating Pandoc documents.
    .
    @Text.Pandoc.Walk@ provides faster, nongeneric functions
    for manipulating Pandoc documents.
    .
    @Text.Pandoc.JSON@ provides functions for serializing
    and deserializing a @Pandoc@ structure to and from JSON.
category: Text
abi: 7e498bc96ed2af970081590e971bf5bc
exposed: True
exposed-modules:
    Text.Pandoc.Arbitrary Text.Pandoc.Builder Text.Pandoc.Definition
    Text.Pandoc.Generic Text.Pandoc.JSON Text.Pandoc.Walk
hidden-modules: Paths_pandoc_types
import-dirs: /usr/lib/ghc-8.6.5/site-local/pandoc-types-1.17.6
library-dirs: /usr/lib/ghc-8.6.5/site-local/pandoc-types-1.17.6
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/pandoc-types-1.17.6
hs-libraries: HSpandoc-types-1.17.6-KQKyc92FMn2LeLAWyyofXw
depends:
    QuickCheck-2.13.2-2FrYL0Zx0JL1157x99MUYA
    aeson-1.4.4.0-CNxP0F7FYeU7wjnur6PUp4 base-4.12.0.0
    bytestring-0.10.8.2 containers-0.6.0.1 deepseq-1.4.4.0
    ghc-prim-0.5.3 syb-0.7.1-1gO4OjQOULM8usUjWwwEyW
    transformers-0.5.6.2
haddock-interfaces: /usr/share/doc/haskell-pandoc-types/html/pandoc-types.haddock
haddock-html: /usr/share/doc/haskell-pandoc-types/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-pandoc-types-1.17.6-5-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-pandoc-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pandoc-types
version: 1.17.6
id: pandoc-types-1.17.6-1vlaY2HgDGZK9PuQHq7zzg
key: pandoc-types-1.17.6-1vlaY2HgDGZK9PuQHq7zzg
license: BSD-3-Clause
copyright: (c) 2006-2019 John MacFarlane
maintainer: jgm@berkeley.edu
author: John MacFarlane
homepage: https://pandoc.org/
synopsis: Types for representing a structured document
description:
    @Text.Pandoc.Definition@ defines the '\''Pandoc'\'' data
    structure, which is used by pandoc to represent
    structured documents.  This module used to live
    in the pandoc package, but starting with pandoc 1.7, it
    has been split off, so that other packages can use it
    without drawing in all of pandoc'\''s dependencies, and
    pandoc itself can depend on packages (like citeproc-hs)
    that use them.
    .
    @Text.Pandoc.Builder@ provides functions for building
    up @Pandoc@ structures programmatically.
    .
    @Text.Pandoc.Generic@ provides generic functions for
    manipulating Pandoc documents.
    .
    @Text.Pandoc.Walk@ provides faster, nongeneric functions
    for manipulating Pandoc documents.
    .
    @Text.Pandoc.JSON@ provides functions for serializing
    and deserializing a @Pandoc@ structure to and from JSON.
category: Text
abi: 9eeff5e638d85fb256bec285c5a87970
exposed: True
exposed-modules:
    Text.Pandoc.Arbitrary Text.Pandoc.Builder Text.Pandoc.Definition
    Text.Pandoc.Generic Text.Pandoc.JSON Text.Pandoc.Walk
hidden-modules: Paths_pandoc_types
import-dirs: /usr/lib/ghc-8.6.5/site-local/pandoc-types-1.17.6
library-dirs: /usr/lib/ghc-8.6.5/site-local/pandoc-types-1.17.6
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/pandoc-types-1.17.6
hs-libraries: HSpandoc-types-1.17.6-1vlaY2HgDGZK9PuQHq7zzg
depends:
    QuickCheck-2.13.2-C3chvSwT3GSBClgQ9bo1MW
    aeson-1.4.4.0-B759jesA16BBzbLoqI31GW base-4.12.0.0
    bytestring-0.10.8.2 containers-0.6.0.1 deepseq-1.4.4.0
    ghc-prim-0.5.3 syb-0.7.1-1gO4OjQOULM8usUjWwwEyW
    transformers-0.5.6.2
haddock-interfaces: /usr/share/doc/haskell-pandoc-types/html/pandoc-types.haddock
haddock-html: /usr/share/doc/haskell-pandoc-types/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
